@@ -32,6 +32,7 @@ from ..pubsub import PubSubClient
 from ..extra_configs import logging_config
 from ..irc import Irc
 from ..util import get_oauth_token_info, _check_token
+from ..translations import translate
 
 if TYPE_CHECKING:
     from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription, PubSubPollData, PubSubFollow
@@ -305,9 +306,9 @@ class BaseBot:
             forward_event(Event.on_after_command_execute, msg, cmd, channel=msg.channel_name)
 
     async def _send_cmd_help(self, msg: Message, cmd: Command, exc: InvalidArgumentsError):
-        await msg.reply(
-            f'{exc.reason} - "{cmd.fullname} {cmd.syntax}" - do "{get_command_prefix()}help {cmd.fullname}" for more details')
-
+        await msg.reply(translate(
+            'send_command_help_message', reason=exc.reason, cmd_fullname=cmd.fullname, command_prefix=get_command_prefix(), cmd_syntax=cmd.syntax
+        ))
     # kept if needed later
     # def _load_overrides(self):
     #     for k, v in overrides.items():
@@ -348,10 +349,11 @@ class BaseBot:
         from ..command import load_commands_from_directory
         from ..modloader import load_mods_from_directory, ensure_commands_folder_exists, ensure_mods_folder_exists
         from ..command_server import start_command_server
-        from .._bot_package_path import _BOT_PACKAGE_PATH
+        from ..bot_package_path import get_bot_package_path
 
-        load_commands_from_directory(os.path.join(_BOT_PACKAGE_PATH, 'builtin_commands'))
-        load_mods_from_directory(os.path.join(_BOT_PACKAGE_PATH, 'builtin_mods'))
+        bot_package_path = get_bot_package_path()
+        load_commands_from_directory(os.path.join(bot_package_path, 'builtin_commands'))
+        load_mods_from_directory(os.path.join(bot_package_path, 'builtin_mods'))
 
         ensure_mods_folder_exists()
         ensure_commands_folder_exists()
